@@ -29,6 +29,8 @@
 #include <TelepathyQt/Channel>
 #include <TelepathyQt/TextChannel>
 #include <TelepathyQt/IncomingFileTransferChannel>
+#include <TelepathyQt/IncomingStreamTubeChannel>
+
 
 class KTpApproverModule : public KDEDModule
 {
@@ -56,6 +58,9 @@ public:
         channelFactory->addFeaturesForIncomingFileTransfers(
                 Tp::IncomingFileTransferChannel::FeatureCore);
 
+        channelFactory->addFeaturesForIncomingStreamTubes(
+                    Tp::IncomingStreamTubeChannel::FeatureCore);
+
         Tp::ContactFactoryPtr contactFactory =
             Tp::ContactFactory::create(Tp::Features()
                                         << Tp::Contact::FeatureAlias
@@ -69,7 +74,7 @@ public:
 
     static inline KAboutData aboutData()
     {
-        KAboutData aboutData("ktp-approver", "kded_ktp_approver", KLocalizedString(), "0.4.1",
+        KAboutData aboutData("ktp-approver", "kded_ktp_approver", KLocalizedString(), "0.5",
                              KLocalizedString(), KAboutData::License_LGPL,
                              ki18nc("@info:credit", "(C) 2010, Collabora Ltd."));
         aboutData.addAuthor(ki18nc("@info:credit", "George Kiagiadakis"),
